define('ember-foundation-apps/foundation', ['exports', 'ember'], function (exports, Ember) {

  'use strict';

  var Foundation = Ember['default'].Object.extend(Ember['default'].ActionHandler, {
    mediaQueries: {},
    namedQueries: {
      'default' : 'only screen',
      landscape : 'only screen and (orientation: landscape)',
      portrait : 'only screen and (orientation: portrait)',
      retina : 'only screen and (-webkit-min-device-pixel-ratio: 2),' +
      'only screen and (min--moz-device-pixel-ratio: 2),' +
      'only screen and (-o-min-device-pixel-ratio: 2/1),' +
      'only screen and (min-device-pixel-ratio: 2),' +
      'only screen and (min-resolution: 192dpi),' +
      'only screen and (min-resolution: 2dppx)'
    },
    actions: {
      resize: function(msg) {
        console.log(msg);
      }
    },
    init: function() {
      var mediaQueries,
      extractedMedia,
      mediaObject,
      o = this;

      o.headerHelper(['foundation-mq']);
      extractedMedia = o.getStyle('.foundation-mq', 'font-family');
      mediaQueries = o.parseStyleToObject(extractedMedia);

      for ( var key in mediaQueries ) {
        mediaQueries[key] = 'only screen and (min-width: ' + mediaQueries[key].replace('rem', 'em') + ')';
      }

      o.set('mediaQueries', Ember['default'].merge(o.get('mediaQueries'), mediaQueries));
      Ember['default'].$(window).resize(function(){
        Ember['default'].run.throttle(o, o.send, 'resize', 'window resized', 50, true);
      });
    },
    headerHelper: function(classArray) {
      var i = classArray.length;
      var head = Ember['default'].$(document.querySelectorAll('head'));

      while(i--) {
        head.append('<meta class="' + classArray[i] + '" />');
      }

      return;
    },
    getStyle: function(selector, styleName) {
      var elem  = document.querySelectorAll(selector)[0];
      var style = window.getComputedStyle(elem, null);

      return style.getPropertyValue('font-family');
    },
    parseStyleToObject: function(str) {
      var styleObject = {};

      if (typeof str !== 'string') {
        return styleObject;
      }

      str = str.trim().slice(1, -1);

      if (!str) {
        return styleObject;
      }

      styleObject = str.split('&').reduce(function(ret, param) {
        var parts = param.replace(/\+/g, ' ').split('=');
        var key = parts[0];
        var val = parts[1];
        key = decodeURIComponent(key);

        val = val === undefined ? null : decodeURIComponent(val);

        if (!ret.hasOwnProperty(key)) {
          ret[key] = val;
        } else if (Array.isArray(ret[key])) {
          ret[key].push(val);
        } else {
          ret[key] = [ret[key], val];
        }
        return ret;
      }, {});

      return styleObject;
    },
    match: function(scenarios) {
      var count   = scenarios.length;
      var queries = this.get('mediaQueries');
      var matches = [];

      if (count > 0) {
        while (count--) {
          var mq;
          var rule = scenarios[count].media;

          if (queries[rule]) {
            mq = matchMedia(queries[rule]);
          } else {
            mq = matchMedia(rule);
          }

          if (mq.matches) {
            matches.push({ ind: count});
          }
        }
      }

      return matches;
    },
    collectScenariosFromElement: function(parentElement) {
      var scenarios = [];
      var templates = [];

      var elements = parentElement.children();
      var i        = 0;
      console.log(elements);

      elements.forEach(function(el) {
        var elem = Ember['default'].$(el);


        //if no source or no html, capture element itself
        if (!elem.attr('src') || !elem.attr('src').match(/.html$/)) {
          templates[i] = elem;
          scenarios[i] = { media: elem.attr('media'), templ: i };
        } else {
          scenarios[i] = { media: elem.attr('media'), src: elem.attr('src') };
        }

        i++;
      });

      return {
        scenarios: scenarios,
        templates: templates
      };
    },
  });

  exports['default'] = Foundation;

});