define("ember-foundation-apps", ["ember-foundation-apps/index","exports"], function(__index__, __exports__) {
  "use strict";
  Object.keys(__index__).forEach(function(key){
    __exports__[key] = __index__[key];
  });
});

define('ember-foundation-apps/components/zf-accordion-item', ['exports', 'ember', 'ember-foundation-apps/mixins/zf-animation'], function (exports, Ember, ZfAnimationMixin) {

  'use strict';

  var ZfAccordionItemComponent = Ember['default'].Component.extend( ZfAnimationMixin['default'], {
    classNames: ['accordion-item'],

    actions: {
      toggleItem: function() {
        this.get('parentView').send('toggleChild', this);
      }
    }
  });

  exports['default'] = ZfAccordionItemComponent;

});
define('ember-foundation-apps/components/zf-accordion', ['exports', 'ember'], function (exports, Ember) {

  'use strict';

  var ZfAccordionComponent = Ember['default'].Component.extend({
    classNames: ['accordion'],
    autoOpen: true,

    actions: {
      toggleChild: function(item) {
        this.get('childViews').forEach(function(i){
          if ( item === i ) {
            i.toggleProperty('isActive');
          } else {
            i.set('isActive', false);
          }
        });
      }
    }
  });

  exports['default'] = ZfAccordionComponent;

});
define('ember-foundation-apps/components/zf-action-sheet', ['exports', 'ember', 'ember-foundation-apps/mixins/zf-animation'], function (exports, Ember, ZfAnimationMixin) {

  'use strict';

  var ZfActionSheetComponent = Ember['default'].Component.extend( ZfAnimationMixin['default'], {
    classNames: ['action-sheet'],
    classNameBindings: ['position'],
    position: 'bottom',

    initClasses: ['is-active-add', 'is-active-remove'],
    transitionClasses: ['is-active-add-active', 'is-active-remove-active'],

    animationSpeed: 'slow',

    animationIn: (function() {
      var className;
      switch (this.get('position')) {
        case 'top':
          className = 'slideInDown';
        break;

        case 'bottom':
          className = 'slideInUp';
        break;

        case 'left':
          className = 'slideInLeft';
        break;

        case 'right':
          className = 'slideInRight';
        break;
      }
      return className;
    }).property('position'),

    animationOut: (function() {
      var className;
      switch (this.get('position')) {
        case 'top':
          className = 'slideOutUp';
        break;

        case 'bottom':
          className = 'slideOutDown';
        break;

        case 'left':
          className = 'slideOutRight';
        break;

        case 'right':
          className = 'slideOutLeft';
        break;
      }
      return className;
    }).property('position'),
  });

  exports['default'] = ZfActionSheetComponent;

});
define('ember-foundation-apps/components/zf-button', ['exports', 'ember'], function (exports, Ember) {

  'use strict';

  var ZfButton = Ember['default'].Component.extend({
    classNames: ['action-button'],
    tagName: 'button',

    action: 'toggle',
    targetId: false,
    targetType: false,
    targetElement: null,

    click: function() {
      var v;
      if ( this.get('targetElement') === null ) {
        var id = this.get('targetId');
        if ( ! id ) { return false; }

        if ( Ember['default'].View.views.hasOwnProperty(id) ) {
          v = Ember['default'].View.views[id];
          this.set('targetElement', v);
        }
      } else {
        v = this.get('targetElement');
      }
      switch (this.get('action')) {
        case 'toggle':
          v.toggle();
        break;

        case 'open':
          v.enter();
        break;

        case 'close':
          v.leave();
        break;
      }
      return false;
    }
  });

  exports['default'] = ZfButton;

});
define('ember-foundation-apps/components/zf-iconic', ['exports', 'ember'], function (exports, Ember) {

  'use strict';

  var ZfIconicComponent = Ember['default'].Component.extend({
    tagName: 'img',
    classNames: ['iconic'],
    classNameBindings: ['iconClass', 'colorClass', 'sizeClass'],
    attributeBindings: ['iconSrc:src'],

    iconSrc: (function() {
      var icon = 'assets/img/iconic/' + this.get('icon') + '.svg';
      return icon;
    }).property('icon'),

    icon: '',
    iconClass: (function() {
      return 'iconic-' + this.get('icon');
    }).property('icon'),

    color: '',
    colorClass: (function() {
      return 'iconic-color-' + this.get('color');
    }).property('color'),

    size: '',
    sizeClass: (function() {
      var sizes = {
        small: 'sm',
        medium: 'md',
        large: 'lg'
      };
      return 'iconic-' + sizes[this.get('size')];
    }).property('size'),
  });

  exports['default'] = ZfIconicComponent;

});
define('ember-foundation-apps/components/zf-interchange', ['exports', 'ember', 'ember-foundation-apps/mixins/zf-animation', 'ember-foundation-apps/foundation'], function (exports, Ember, ZfAnimationMixin, Foundation) {

  'use strict';

  var ZfInterchangeComponent = Ember['default'].Component.extend({
    small: false,
    medium: false,
    large: false,

    interchange: (function(){
      console.log(Foundation['default'].get('mediaQueries'));
    }).on('resize'),
  });

  exports['default'] = ZfInterchangeComponent;

});
define('ember-foundation-apps/components/zf-modal', ['exports', 'ember', 'ember-foundation-apps/mixins/zf-animation'], function (exports, Ember, ZfAnimationMixin) {

  'use strict';

  var ZfModalComponent = Ember['default'].Component.extend( ZfAnimationMixin['default'], {
    classNameBindings: ['calculatedClass'],

    calculatedClass: (function() {
      if ( this.get('isOverlay') ) {
        return 'modal-overlay';
      } else {
        return 'modal';
      }
    }).property('isOverlay'),

    animationIn: 'fadeIn',
    animationOut: 'fadeOut',

    isOverlay: true,

    enter: function() {
      this._super();
      this.get('childViews').forEach(function(item){
        item.enter();
      });
    },
    leave: function() {
      this._super();
      this.get('childViews').forEach(function(item){
        item.leave();
      });
    }
  });

  exports['default'] = ZfModalComponent;

});
define('ember-foundation-apps/components/zf-notification', ['exports', 'ember', 'ember-foundation-apps/mixins/zf-animation'], function (exports, Ember, ZfAnimationMixin) {

  'use strict';

  var ZfNotificationComponent = Ember['default'].Component.extend( ZfAnimationMixin['default'], {
    classNameBindings: ['typeClass', 'position'],

    type: 'static',
    isDynamic: Ember['default'].computed.equal('type', 'dynamic'),
    typeClass: (function() {
      var className;
      switch (this.get('type')) {
        case 'static':
          className = 'static-notification';
        break;

        case 'dynamic':
          className = 'notification-container';
        break;

        case 'child':
          className = 'notification';
        break;
      }

      return className;
    }).property('type'),

    title: "",
    image: false,
    position: 'top-right',
    notifications: Ember['default'].ArrayProxy.create(),
  });

  exports['default'] = ZfNotificationComponent;

});
define('ember-foundation-apps/components/zf-off-canvas', ['exports', 'ember', 'ember-foundation-apps/mixins/zf-animation'], function (exports, Ember, ZfAnimationMixin) {

  'use strict';

  var ZfOffCanvasComponent = Ember['default'].Component.extend( ZfAnimationMixin['default'], {
    classNames: ['off-canvas'],
    classNameBindings: ['position'],

    position: 'top',

    initClasses: ['is-active-add', 'is-active-remove'],
    transitionClasses: ['is-active-add-active', 'is-active-remove-active'],

    animationIn: (function() {
      var className;
      switch (this.get('position')) {
        case 'top':
          className = 'slideInDown';
        break;

        case 'bottom':
          className = 'slideInUp';
        break;

        case 'left':
          className = 'slideInLeft';
        break;

        case 'right':
          className = 'slideInRight';
        break;
      }
      return className;
    }).property('position'),

    animationOut: (function() {
      var className;
      switch (this.get('position')) {
        case 'top':
          className = 'slideOutUp';
        break;

        case 'bottom':
          className = 'slideOutDown';
        break;

        case 'left':
          className = 'slideOutRight';
        break;

        case 'right':
          className = 'slideOutLeft';
        break;
      }
      return className;
    }).property('position')
  });

  exports['default'] = ZfOffCanvasComponent;

});
define('ember-foundation-apps/components/zf-panel', ['exports', 'ember', 'ember-foundation-apps/mixins/zf-animation'], function (exports, Ember, ZfAnimationMixin) {

  'use strict';

  var ZfPanelComponent = Ember['default'].Component.extend( ZfAnimationMixin['default'], {
    classNames: ['panel'],
    classNameBindings: ['positionClass'],

    position: 'top',
    positionClass: (function() {
      return 'panel-' + this.get('position');
    }).property('position'),

    animationIn: (function() {
      var className;
      switch (this.get('position')) {
        case 'top':
          className = 'slideInDown';
        break;

        case 'bottom':
          className = 'slideInUp';
        break;

        case 'left':
          className = 'slideInLeft';
        break;

        case 'right':
          className = 'slideInRight';
        break;
      }
      return className;
    }).property('position'),

    animationOut: (function() {
      var className;
      switch (this.get('position')) {
        case 'top':
          className = 'slideOutUp';
        break;

        case 'bottom':
          className = 'slideOutDown';
        break;

        case 'left':
          className = 'slideOutRight';
        break;

        case 'right':
          className = 'slideOutLeft';
        break;
      }
      return className;
    }).property('position'),
  });

  exports['default'] = ZfPanelComponent;

});
define('ember-foundation-apps/components/zf-tab-item', ['exports', 'ember', 'ember-foundation-apps/mixins/zf-animation'], function (exports, Ember, ZfAnimationMixin) {

  'use strict';

  var ZfTabItemComponent = Ember['default'].Component.extend( ZfAnimationMixin['default'], {
    classNames: ['tab-item'],

    click: function() {
      this.get('parentView').send('toggleChild', this);
    }
  });

  exports['default'] = ZfTabItemComponent;

});
define('ember-foundation-apps/components/zf-tabs', ['exports', 'ember'], function (exports, Ember) {

  'use strict';

  var ZfTabsComponent = Ember['default'].Component.extend({
    classNames: ['tabs-container'],
    autoOpen: true,

    actions: {
      toggleChild: function(item) {
        var v = this, contents;
        v.get('childViews').forEach(function(i, index) {
          contents = v.$().find('.tab-contents').children().eq(index);
          if ( item === i ) {
            contents.toggleClass('is-active');
            i.toggleProperty('isActive');
          } else {
            contents.removeClass('is-active');
            i.set('isActive', false);
          }
        });
      }
    },

    didInsertElement: function() {
      var v = this, content;
      Ember['default'].$(document).ready(function(){
        v.$().find('.tab-item').each(function(){
          content = Ember['default'].$(this).find('.tab-content');
          v.$().find('.tab-contents').append(content.clone());
          content.remove();
        });
      });
    }
  });

  exports['default'] = ZfTabsComponent;

});
define('ember-foundation-apps/foundation', ['exports', 'ember'], function (exports, Ember) {

  'use strict';

  var Foundation = Ember['default'].Object.extend(Ember['default'].ActionHandler, {
    mediaQueries: {},
    namedQueries: {
      'default' : 'only screen',
      landscape : 'only screen and (orientation: landscape)',
      portrait : 'only screen and (orientation: portrait)',
      retina : 'only screen and (-webkit-min-device-pixel-ratio: 2),' +
      'only screen and (min--moz-device-pixel-ratio: 2),' +
      'only screen and (-o-min-device-pixel-ratio: 2/1),' +
      'only screen and (min-device-pixel-ratio: 2),' +
      'only screen and (min-resolution: 192dpi),' +
      'only screen and (min-resolution: 2dppx)'
    },
    actions: {
      resize: function(msg) {
        console.log(msg);
      }
    },
    init: function() {
      var mediaQueries,
      extractedMedia,
      mediaObject,
      o = this;

      o.headerHelper(['foundation-mq']);
      extractedMedia = o.getStyle('.foundation-mq', 'font-family');
      mediaQueries = o.parseStyleToObject(extractedMedia);

      for ( var key in mediaQueries ) {
        mediaQueries[key] = 'only screen and (min-width: ' + mediaQueries[key].replace('rem', 'em') + ')';
      }

      o.set('mediaQueries', Ember['default'].merge(o.get('mediaQueries'), mediaQueries));
      Ember['default'].$(window).resize(function(){
        Ember['default'].run.throttle(o, o.send, 'resize', 'window resized', 50, true);
      });
    },
    headerHelper: function(classArray) {
      var i = classArray.length;
      var head = Ember['default'].$(document.querySelectorAll('head'));

      while(i--) {
        head.append('<meta class="' + classArray[i] + '" />');
      }

      return;
    },
    getStyle: function(selector, styleName) {
      var elem  = document.querySelectorAll(selector)[0];
      var style = window.getComputedStyle(elem, null);

      return style.getPropertyValue('font-family');
    },
    parseStyleToObject: function(str) {
      var styleObject = {};

      if (typeof str !== 'string') {
        return styleObject;
      }

      str = str.trim().slice(1, -1);

      if (!str) {
        return styleObject;
      }

      styleObject = str.split('&').reduce(function(ret, param) {
        var parts = param.replace(/\+/g, ' ').split('=');
        var key = parts[0];
        var val = parts[1];
        key = decodeURIComponent(key);

        val = val === undefined ? null : decodeURIComponent(val);

        if (!ret.hasOwnProperty(key)) {
          ret[key] = val;
        } else if (Array.isArray(ret[key])) {
          ret[key].push(val);
        } else {
          ret[key] = [ret[key], val];
        }
        return ret;
      }, {});

      return styleObject;
    },
    match: function(scenarios) {
      var count   = scenarios.length;
      var queries = this.get('mediaQueries');
      var matches = [];

      if (count > 0) {
        while (count--) {
          var mq;
          var rule = scenarios[count].media;

          if (queries[rule]) {
            mq = matchMedia(queries[rule]);
          } else {
            mq = matchMedia(rule);
          }

          if (mq.matches) {
            matches.push({ ind: count});
          }
        }
      }

      return matches;
    },
    collectScenariosFromElement: function(parentElement) {
      var scenarios = [];
      var templates = [];

      var elements = parentElement.children();
      var i        = 0;
      console.log(elements);

      elements.forEach(function(el) {
        var elem = Ember['default'].$(el);


        //if no source or no html, capture element itself
        if (!elem.attr('src') || !elem.attr('src').match(/.html$/)) {
          templates[i] = elem;
          scenarios[i] = { media: elem.attr('media'), templ: i };
        } else {
          scenarios[i] = { media: elem.attr('media'), src: elem.attr('src') };
        }

        i++;
      });

      return {
        scenarios: scenarios,
        templates: templates
      };
    },
  });

  exports['default'] = Foundation;

});
define('ember-foundation-apps/index', ['exports', 'ember-foundation-apps/foundation', 'ember-foundation-apps/mixins/zf-animation', 'ember-foundation-apps/components/zf-button', 'ember-foundation-apps/components/zf-panel', 'ember-foundation-apps/components/zf-off-canvas', 'ember-foundation-apps/components/zf-modal', 'ember-foundation-apps/components/zf-notification', 'ember-foundation-apps/components/zf-accordion', 'ember-foundation-apps/components/zf-accordion-item', 'ember-foundation-apps/components/zf-tabs', 'ember-foundation-apps/components/zf-tab-item', 'ember-foundation-apps/components/zf-iconic', 'ember-foundation-apps/components/zf-interchange'], function (exports, Foundation, ZfAnimationMixin, ZfButtonComponent, ZfPanelComponent, ZfOffCanvasComponent, ZfModalComponent, ZfNotificationComponent, ZfAccordion, ZfAccordionItem, ZfTabs, ZfTabItem, ZfIconic, ZfInterchange) {

  'use strict';



  exports.Foundation = Foundation['default'];
  exports.ZfAnimationMixin = ZfAnimationMixin['default'];
  exports.ZfButtonComponent = ZfButtonComponent['default'];
  exports.ZfPanelComponent = ZfPanelComponent['default'];
  exports.ZfOffCanvasComponent = ZfOffCanvasComponent['default'];
  exports.ZfModalComponent = ZfModalComponent['default'];
  exports.ZfNotificationComponent = ZfNotificationComponent['default'];
  exports.ZfAccordion = ZfAccordion['default'];
  exports.ZfAccordionItem = ZfAccordionItem['default'];
  exports.ZfTabs = ZfTabs['default'];
  exports.ZfTabItem = ZfTabItem['default'];
  exports.ZfIconic = ZfIconic['default'];
  exports.ZfInterchange = ZfInterchange['default'];

});
define('ember-foundation-apps/mixins/zf-animation', ['exports', 'ember'], function (exports, Ember) {

  'use strict';

  var ZfAnimationMixin = Ember['default'].Mixin.create({
    isActive: false,
    classNameBindings: ['isActive', 'animationEasing', 'animationSpeed'],

    animationIn: 'fadeIn',
    animationOut: 'fadeOut',
    animationEasing: 'linear',
    animationSpeed: 'default',

    initClasses: ['ng-enter', 'ng-leave'],
    transitionClasses: ['ng-enter-active', 'ng-leave-active'],

    transitionSpeed: (function() {
      var speeds = {
        'slow': 750,
        'default': 500,
        'fast': 250,
      };
      return speeds[this.get('animationSpeed')];
    }).property('animationSpeed'),

    willTransitionIn: function() {
      this.set('isActive', true);
      console.log(1, this.$().attr('class'));
      this.$().addClass(this.get('initClasses.firstObject') + ' ' + this.get('animationIn'));
      console.log(1, this.$().attr('class'));
    },

    transitionIn: function(callback) {
      console.log(2, this.$().attr('class'));
      this.$().addClass(this.get('transitionClasses.firstObject'));
      console.log(2, this.$().attr('class'));
      callback();
    },

    didTransitionIn: function() {
      console.log(3, this.$().attr('class'));
      this.$().removeClass(this.get('initClasses.firstObject') +  ' ' + this.get('transitionClasses.firstObject') + ' ' + this.get('animationIn'));
      console.log(3, this.$().attr('class'));
    },

    willTransitionOut: function() {
      console.log(-1, this.$().attr('class'));
      this.$().addClass(this.get('initClasses.lastObject') + ' ' + this.get('animationOut'));
      console.log(-1, this.$().attr('class'));
    },

    transitionOut: function(callback) {
      console.log(-2, this.$().attr('class'));
      this.$().addClass(this.get('transitionClasses.lastObject'));
      console.log(-2, this.$().attr('class'));
      callback();
    },

    didTransitionOut: function() {
      this.set('isActive', false);
      console.log(-3, this.$().attr('class'));
      this.$().removeClass(this.get('initClasses.lastObject') + ' ' + this.get('transitionClasses.lastObject') + ' ' + this.get('animationOut'));
      console.log(-3, this.$().attr('class'));
    }
  });

  exports['default'] = ZfAnimationMixin;

});//# sourceMappingURL=addons.map